# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [v0.5.0] - 2025-02-21

- switch to astral tools
- require python 3.9

## [v0.4.0] - 2023-05-02

- require python 3.8
- update dependencies
- update tools
- move from flake8 & pyupgrade to ruff
- fix coverage

## [v0.3.1] - 2023-02-05

- read inline images

## [v0.3.0] - 2022-10-17

- type hints

## [v0.2.0] - 2022-10-17

- fork
- update tooling (poetry, black, isort, pre-commit)
- drop nosetests for unittest

## [v0.1.4] - 2022-10-17

- transitional fork tag

## [v0.1.3] - 2017-11-20

- Latest version from @yejianye

[Unreleased]: https://github.com/nim65s/nmdmail/compare/v0.5.0...main
[v0.5.0]: https://github.com/nim65s/nmdmail/compare/v0.4.0...v0.5.0
[v0.4.0]: https://github.com/nim65s/nmdmail/compare/v0.3.1...v0.4.0
[v0.3.1]: https://github.com/nim65s/nmdmail/compare/v0.3.0...v0.3.1
[v0.3.0]: https://github.com/nim65s/nmdmail/compare/v0.2.0...v0.3.0
[v0.2.0]: https://github.com/nim65s/nmdmail/compare/v0.1.4...v0.2.0
[v0.1.4]: https://github.com/nim65s/nmdmail/releases/tag/v0.1.4
[v0.1.3]: https://github.com/yejianye/mdmail
